@@ -28,8 +28,6 @@ async fn db_migration() -> Result<(), PgEmbedError> {
     let db_name = "test";
     pg.create_database(&db_name).await?;
     assert!(pg.database_exists(&db_name).await?);
-    pg.drop_database(&db_name).await?;
-    assert!(!pg.database_exists(&db_name).await?);
     pg.migrate(&db_name).await?;
     Ok(())
 }
